# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.12.0-rc3
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictStr, conlist
from polyaxon_sdk.models.v1_status_condition import V1StatusCondition
from polyaxon_sdk.models.v1_statuses import V1Statuses

class V1Status(BaseModel):
    """
    V1Status
    """
    uuid: Optional[StrictStr] = None
    status: Optional[V1Statuses] = None
    status_conditions: Optional[conlist(V1StatusCondition)] = None
    meta_info: Optional[Dict[str, Any]] = None
    __properties = ["uuid", "status", "status_conditions", "meta_info"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Status:
        """Create an instance of V1Status from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in status_conditions (list)
        _items = []
        if self.status_conditions:
            for _item in self.status_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['status_conditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Status:
        """Create an instance of V1Status from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Status.parse_obj(obj)

        _obj = V1Status.parse_obj({
            "uuid": obj.get("uuid"),
            "status": obj.get("status"),
            "status_conditions": [V1StatusCondition.from_dict(_item) for _item in obj.get("status_conditions")] if obj.get("status_conditions") is not None else None,
            "meta_info": obj.get("meta_info")
        })
        return _obj

